@@ -245,7 +245,7 @@ class Builder(Update):
                     subbuild = 0
                 data.append({
                     'dist': info['os_linux_shortname'],
-                    'release': info['os_linux_ver'],
+                    'release': "live",
                     'arch': info['os_arch_machine'],
                     'variant': "default",
                     'name': info['os_linux_name'],
