@@ -330,6 +330,13 @@ class ClBuilderUpdateAction(Action):
                 {'name': 'update_other:check_obsolete',
                  'method': 'Builder.check_obsolete(cl_builder_path)'
                  },
+                {'name': 'update_world:set_latest_tag',
+                 'method': 'Builder.set_current_saved_tag()',
+                 'depend': (Tasks.success() & Tasks.hasnot("interrupt") &
+                     Tasks.hasnot("check_schedule")), 
+                 'condition': lambda Get: Get('update.cl_update_sync_only_set') == 'off' and
+                         Get('update.cl_update_pretend_set') == 'off'
+                 },
             ] + [
                 {'name': 'failed',
                  'error': __("Failed to update the system"),
